@@ -1,5 +1,15 @@
 #![allow(unused_variables)]
 
+use crate::bindings::Windows::Win32::UI::WindowsAndMessaging::*;
+
+#[derive(Debug)]
+pub struct OtherParams {
+    pub hwnd: HWND,
+    pub message: u32,
+    pub wparam: WPARAM,
+    pub lparam: LPARAM,
+}
+
 #[cfg(feature = "raw_input")]
 use crate::raw_input;
 use crate::{device::*, geometry::*, ime::*, window::Window};
@@ -109,4 +119,8 @@ pub trait EventHandler {
         state: raw_input::DeviceChangeState,
     ) {
     }
+
+    fn other(&mut self, params: &OtherParams) -> Option<i32> {
+        None
+    }
 }
