@@ -118,7 +118,7 @@ fn key_input<T: EventHandler + 'static>(
     call_handler(|eh: &mut T, _| {
         eh.key_input(
             window,
-            KeyCode::new(as_virtual_key(wparam.0 as i32), scan_code),
+            KeyCode::new(as_virtual_key(wparam.0 as u32), scan_code),
             state,
             (lparam.0 >> 30) & 0x01 != 0,
         );
@@ -541,11 +541,13 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     w if w == UserMessage::AcceptDragFiles as usize => {
                         DragAcceptFiles(hwnd, BOOL(lparam.0 as _));
                     }
-                    _ => unreachable!(),
+                    _ => {
+                        return call_other::<T>(hwnd, msg, wparam, lparam);
+                    },
                 }
                 LRESULT(0)
             }
-            _ => DefWindowProcW(hwnd, msg, wparam, lparam),
+            _ => call_other::<T>(hwnd, msg, wparam, lparam),
         }
     });
     ret.unwrap_or_else(|e| {
